@@ -1,8 +1,8 @@
 from file_stream.executor import Executor, MysqlExecutor
 import csv
-import logging
 import copy
-from typing import List
+from typing import List, Dict
+import redis
 
 
 class CsvWriter(Executor):
@@ -16,18 +16,21 @@ class CsvWriter(Executor):
         super().__init__()
         self.stream = open(fpath, 'w')
         self.writer = csv.DictWriter(self.stream, fieldnames=fieldnames, delimiter=kwargs.get('delimiter', ','))
-        self.writer.writeheader()
+        if kwargs.get('write_header', True):
+            self.writer.writeheader()
 
     def output(self):
         if self._source is None:
             raise IOError('未指定来源')
         for item in self._source:
+            self.counter['total'] += 1
             self.writer.writerow(item)
         self.stream.close()
 
     def writerow(self, row: dict):
         assert isinstance(row, dict), '输入必须是字典。'
         self.writer.writerow(row)
+        self.counter['total'] += 1
 
 
 class MysqlWriter(MysqlExecutor):
@@ -54,7 +57,7 @@ class MysqlWriter(MysqlExecutor):
             sql = 'insert into {} ({}) values (%({})s)'.format(self.table_name, field_names, field_values)
             self.cur.execute(sql, item)
         self.db.commit()
-        self.logger.debug('sql commit')
+        self.counter['total'] += len(items)
 
     def output(self):
         if self._source is None:
@@ -107,6 +110,7 @@ class MysqlUpdateWriter(MysqlExecutor):
         for item in items:
             self.cur.execute(sql, item)
         self.db.commit()
+        self.counter['write'] += len(items)
 
     def _update_many(self, items: list):
         assert isinstance(items, list) and len(items) > 0, '输入只能是list,且长度大于0。'
@@ -123,6 +127,8 @@ class MysqlUpdateWriter(MysqlExecutor):
             if result.rowcount == 0:
                 miss_update.append(item)
         self.db.commit()
+        self.counter['update'] += (len(items) - len(miss_update))
+
         if self.write_fail and len(miss_update) > 0:
             self._output_many(miss_update)
 
@@ -161,8 +167,8 @@ class MysqlDel(MysqlWriter):
             results = self.cur.execute(sql, item, multi=True)
             result = next(results)
             self.logger.debug("Number of rows affected by statement '{}': {}".format(result.statement, result.rowcount))
+            self.counter['total'] += result.rowcount
         self.db.commit()
-        self.logger.debug('sql commit')
 
     def output(self):
         if self._source is None:
@@ -199,3 +205,16 @@ class ScreenOutput(Executor):
 
     def writerow(self, row: dict):
         print(row, end=self.end)
+
+
+class RedisWriter(Executor):
+    def __init__(self, redis_config: dict, **kwargs):
+        super().__init__(**kwargs)
+        self.writer = redis.Redis(**redis_config)
+
+    def add_value(self, item: dict):
+        for key, value in item.items():
+            self.writer.append(key, value)
+
+
+
